@@ -1,6 +1,6 @@
 /**************************************************************************
  * BaseString - Functions for manipulation the string.
- * Version:     0.3.7 19/02/2006
+ * Version:     0.3.8 14/10/2007
  * File:        BaseString.c
  * Description: Tools of survival to the string. 
  * Error:       ID file 1, last number 09
@@ -139,12 +139,12 @@ int strcatV (char *StrOut, char *StrIn, long LenBuff){
     strncatV (StrOut, StrIn, LenBuff, LenBuff);
     if (!result){
       sprintf (str, "%d", LenBuff);
-      ElAddErr (106, "BS", _("With append %s the value %s is longer than %s"), StrIn, StrOut, str);
+      ElAddErr (106, "BS", (char *)_("With append %s the value %s is longer than %s"), StrIn, StrOut, str);
     }
   }
   else{
     sprintf (str, "%d", LenBuff);
-    ElAddErr2 (105, "BS", _("The value %s is longer than %s"), StrOut, str);
+    ElAddErr2 (105, "BS",(char *)_("The value %s is longer than %s"), StrOut, str);
   }
 
   return (result);
@@ -164,7 +164,7 @@ int strcpyV (char *StrOut, char *StrIn, long LenBuff){
   strncpyV (StrOut, StrIn, LenBuff, LenBuff);
   if (!result){
     sprintf (str, "%d", LenBuff);
-    ElAddErr2 (104, "BS", _("The value %s is longer than %s"), StrIn, str);
+    ElAddErr2 (104, "BS", (char *)_("The value %s is longer than %s"), StrIn, str);
   }
 
   return (result);
@@ -202,12 +202,12 @@ int strncatV (char *StrOut, char *StrIn, long num, long LenBuff){
 
     if (!result){
       sprintf (str, "%d", LenBuff);
-      ElAddErr (103, "BS", _("With append %s the value %s is longer than %s"), StrIn, StrOut, str);
+      ElAddErr (103, "BS", (char *)_("With append %s the value %s is longer than %s"), StrIn, StrOut, str);
     }
   } // if (result= strlen (StrOut) <= LenBuff)
   else{
     sprintf (str, "%d", LenBuff);
-    ElAddErr2 (102, "BS", _("The value %s is longer than %s"), StrOut, str);
+    ElAddErr2 (102, "BS", (char *)_("The value %s is longer than %s"), StrOut, str);
   }
 
   return (result);
@@ -239,7 +239,7 @@ int strncpyV (char *StrOut, char *StrIn, long num, long LenBuff){
 
   if (!result){
     sprintf (str, "%d", LenBuff);
-    ElAddErr2 (101, "BS", _("The value %s is longer than %s"), StrIn, str);
+    ElAddErr2 (101, "BS", (char *)_("The value %s is longer than %s"), StrIn, str);
   }
 
   return (result);
@@ -304,7 +304,7 @@ int strrepl (char *StrTo, char *StrFor, char *StrRepl, long LenBuff){
 
   if (!result){
     sprintf (str, "%d", LenBuff);
-    ElAddErr2 (107, "BS", _("The replaced value %s is longer than %s"), StrTo, str);
+    ElAddErr2 (107, "BS", (char *)_("The replaced value %s is longer than %s"), StrTo, str);
   }
 
   return (result);
@@ -490,7 +490,7 @@ int AddTxtWithSep (char *TxtOut, char *TxtIn, char *TxtAdd, char *sep, long LenB
     sprintf (TxtOut, "%s%s%s", TxtIn, *TxtIn != '\0' ? sep : "", TxtAdd);
   else{
     sprintf (str, "%d", LenBuff);
-    ElAddErr (108, "FR", _("Adding %s to %s exceeds %s"), TxtAdd, TxtIn, str);
+    ElAddErr (108, "FR", (char *)_("Adding %s to %s exceeds %s"), TxtAdd, TxtIn, str);
   }
 
   return (result);
@@ -517,7 +517,7 @@ int CheckRow (char *RowIn){
 
   if (!result){
     sprintf (str, "%d", MAXLENROWS - 1);
-    ElAddErr2 (109, "BR", _("The line %s is longer then %s"), RowIn, str);
+    ElAddErr2 (109, "BR", (char *)_("The line %s is longer then %s"), RowIn, str);
   }
 
   return (result);
