@@ -1,6 +1,6 @@
 /**************************************************************************
  * FileConf - Functions for the make of the options of the command line. 
- * Version:     0.3.7 05/02/2006
+ * Version:     0.3.8 14/10/2007
  * File:        FileConf.c
  * Description: Functions for the reading, verification, execution of the 
  *              options of the command line. 
@@ -491,7 +491,7 @@ static int SetLockGrpKey (char *GrpIn, char *KeyIn, char *ValKeyIn, char *lock,
       FindGrpKey (GrpIn, KeyIn, ValKeyIn, &RStat, &RowNGrp, &RowNKey);
   }
   else
-    ElAddErr1 (409, "BV", _("The value of lock %s is not managed"), lock);
+    ElAddErr1 (409, "BV", (char *)_("The value of lock %s is not managed"), lock);
 
   if (result){
     RowNum= *KeyIn == '\0' ? RowNGrp : RowNKey;
@@ -657,7 +657,7 @@ static int InsGrpKey (char *grp, char *key, char *val, struct _StatRow *stat, in
   } // if (result= FcRows.NumConf < MAX_NCONFROWS)
   else{
     sprintf(str, "%d", MAX_NCONFROWS);
-    ElAddErr2 (413, "FR", _("With %s the number of inserted lines it exceeds %s"), 
+    ElAddErr2 (413, "FR", (char *)_("With %s the number of inserted lines it exceeds %s"), 
 	    key, str);
   }
 
@@ -743,7 +743,7 @@ static int CheckGrpKey (char *group, char *key, char *ValKey, char *val, char *E
 	    WStatToRStat ("G", &RStat);
 	    FindGrpKey (PrevGrp, "", "", &RStat, &ActRowNGrp, &ActRowNKey);
 	    if (!(result= ActRowNGrp > -1))
-	      ElAddErr1 (405, "BG", _("The group %s is not parent of one group"), group);
+	      ElAddErr1 (405, "BG", (char *)_("The group %s is not parent of one group"), group);
 	  }
 	}
 // set the insert position
@@ -766,7 +766,7 @@ static int CheckGrpKey (char *group, char *key, char *ValKey, char *val, char *E
 	  *EnabType= '\0';
       } // if (result)
       else
-	ElAddErr1 (402, "BK", _("The group and the key is empty"), group);
+	ElAddErr1 (402, "BK", (char *)_("The group and the key is empty"), group);
     } // if (!strcmp (EnabType, "INS"))
     else{
       if (strcmp (EnabType, "GET"))
@@ -777,11 +777,11 @@ static int CheckGrpKey (char *group, char *key, char *ValKey, char *val, char *E
 	result= *ConfPar.WarnType != '\0';
 	if (!result || *ConfPar.WarnType == 'W'){
 	  if (stat->type == 'G')
-	    ElAddErr1 (406, "BG", _("Group %s nonexistent"), group);
+	    ElAddErr1 (406, "BG", (char *)_("Group %s nonexistent"), group);
 	  else if (stat->type == 'K')
-	    ElAddErr (407, "BK", _("Key %s %s %s nonexistent"), group, key, ValKey);
+	    ElAddErr (407, "BK", (char *)_("Key %s %s %s nonexistent"), group, key, ValKey);
 	  else
-	    ElAddErr2 (408, "BV", _("Comment %s %s nonexistent"), group, ValKey);
+	    ElAddErr2 (408, "BV", (char *)_("Comment %s %s nonexistent"), group, ValKey);
 	}
       }
     }
@@ -798,16 +798,16 @@ static int CheckGrpKey (char *group, char *key, char *ValKey, char *val, char *E
       result= *ConfPar.WarnType != '\0';
       if (!result || *ConfPar.WarnType == 'W'){
 	if (GrpLock)
-	  ElAddErr1 (403, "BG", _("The group %s is onlock"), group);
+	  ElAddErr1 (403, "BG", (char *)_("The group %s is onlock"), group);
 	else if (KeyLock)
-	  ElAddErr (404, "BK", _("The key %s %s %s is onlock"), group, key, ValKey);
+	  ElAddErr (404, "BK", (char *)_("The key %s %s %s is onlock"), group, key, ValKey);
       }
     }
   } // if (result && (ChangeGrp || ChangeKey) && *EnabType != '\0')
 // verify is a virtual group
   if (result && ChangeKey && *EnabType != '\0'){
     if (!(result= !ISKEYTOGRP(key)))
-      ElAddErr1 (412, "BK", _("The names of the groups do not have to be modified"), "");
+      ElAddErr1 (412, "BK", (char *)_("The names of the groups do not have to be modified"), "");
   }
   return (result);
 } // CheckGrpKey
@@ -1235,7 +1235,7 @@ static int ReadFile (char *file){
       } // if (result= FcRows.NumConf < MAX_NCONFROWS)
       else{
 	sprintf(str, "%d", MAX_NCONFROWS);
-	ElAddErr2 (414, "FR", _("The number of lines of the file %s exceeds %s"), 
+	ElAddErr2 (414, "FR", (char *)_("The number of lines of the file %s exceeds %s"), 
 		  file, str);
 	break;
       }
@@ -1535,7 +1535,7 @@ static int ConfToFile (char *RowOut, int FormEnab, struct _ConfRow *ActCRow, str
   }
   else{
     sprintf (str, "%d", MAXLENROWS);
-    ElAddErr (410, "FR", _("Adding %s %s to row exceeds %s"), ISGRP(ActCRow->stat.type) ? EndPartGrp : ActCRow->key, 
+    ElAddErr (410, "FR", (char *)_("Adding %s %s to row exceeds %s"), ISGRP(ActCRow->stat.type) ? EndPartGrp : ActCRow->key, 
 	      ActCRow->val, str);
   }
 
@@ -1599,7 +1599,7 @@ static int AddTextConf (char *TextIn, char **TextAdd, int EnabLong){
   }
   else{
     sprintf(str, "%d", MaxNumText);
-    ElAddErr2 (411, "FR", _("With %s the number of row exceeds %s"), TextIn, str);
+    ElAddErr2 (411, "FR", (char *)_("With %s the number of row exceeds %s"), TextIn, str);
   }
   return (result);
 } // AddTextConf
@@ -1661,5 +1661,5 @@ void InitConf (char *tipo){
     ConfPar.pfExeConfVal= NULL;
   }
   else
-    ElAddErr1 (401, "BV", _("The init %s it is not managed"), tipo);     
+    ElAddErr1 (401, "BV", (char *)_("The init %s it is not managed"), tipo);     
 } //InitConf
